@@ -233,7 +233,7 @@ gui_out_grid <- function(vms_db_name = "")
       
       if(sum(count) != 0)
       {
-        plot(themap$data, lty = "blank", 
+        sp::plot(themap$data, lty = "blank", 
              col=s.cols[s.vals], add = T)
         
         map("worldHires", fill=T, col="springgreen4",
@@ -313,7 +313,7 @@ gui_out_grid <- function(vms_db_name = "")
                                ylim=c(themap$data@bbox[2,1]*0.98,themap$data@bbox[2,2])
                            )
                            
-                           plot(themap$data, lty= "blank", 
+                           sp::plot(themap$data, lty= "blank", 
                                 col=s.cols[s.vals], add = T)
                            
                            map("worldHires", fill=T, col="springgreen4",
@@ -391,7 +391,7 @@ gui_out_grid <- function(vms_db_name = "")
         ylim=c(themap$data@bbox[2,1]*0.98,themap$data@bbox[2,2])
     )
     
-    plot(themap$data, lty= "blank", 
+    sp::plot(themap$data, lty= "blank", 
          col=s.cols[s.vals], add = T)
     
     map("worldHires", fill=T, col="springgreen4",
